import { onMount, onDestroy, afterUpdate } from 'svelte';
import SwipeProvider from 'swipe-core-provider';
export default function useSwipe(ref, config) {
    // svelte issue
    let Events = SwipeProvider(1, config);
    const initCb = () => Events.init(ref());
    const handleResize = () => Events.resize(ref());
    let init;
    const events = {
        onTouchStart: (e) => Events.mobileStart(e),
        onTouchMove: (e) => Events.mobileMove(e, ref()),
        onTouchEnd: (e) => Events.mobileEnd(e, ref()),
        onTouchCancel: (e) => Events.mobileEnd(e, ref()),
        onPointerDown: (e) => Events.desktopStart(e),
        onPointerMove: (e) => Events.desktopMove(e, ref()),
        onPointerUp: (e) => Events.desktopEnd(e, ref()),
        onPointerLeave: (e) => Events.desktopEnd(e, ref()),
        onPointerCancel: (e) => Events.desktopEnd(e, ref()),
    };
    afterUpdate(() => {
        Events = SwipeProvider(ref().children.length, config);
        initCb();
    });
    onMount(() => {
        // init
        Events = SwipeProvider(ref().children.length, config);
        if (!config?.isHistory) {
            init = setTimeout(initCb, 0);
        }
        else
            init = setInterval(initCb, 10);
        // swipe pc
        ref().addEventListener('mousedown', events.onPointerDown, {
            passive: true,
        });
        ref().addEventListener('mousemove', events.onPointerMove, {
            passive: true,
        });
        ref().addEventListener('mouseup', events.onPointerUp, {
            passive: true,
        });
        ref().addEventListener('mouseleave', events.onPointerUp, {
            passive: true,
        });
        // swipe mobile
        ref().addEventListener('touchstart', events.onTouchStart, {
            passive: true,
        });
        ref().addEventListener('touchmove', events.onTouchMove, {
            passive: true,
        });
        ref().addEventListener('touchend', events.onTouchEnd, {
            passive: true,
        });
        // resize
        window.addEventListener('resize', handleResize, { passive: true });
    });
    onDestroy(() => {
        // init
        !config?.isHistory ? clearTimeout(init) : clearInterval(init);
        // resize
        if (globalThis.window)
            window.removeEventListener('resize', handleResize);
    });
    return {
        handleSlide: (flag) => Events.slidehandler(flag, ref()),
        changeIndex: (index) => Events.changeIndex(index, ref()),
    };
}
